@@ -1,16 +1,17 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
+import json
 import os
 import shutil
 from pathlib import Path
-import json
+from test.common import movie_data, tmp_dir
 
+import msgpack
 import pytest
 import ruamel.yaml as yaml
 
 from box import BoxError
-from box.converters import _to_toml, _from_toml, _to_json, _to_yaml
-from test.common import tmp_dir, movie_data
-
+from box.converters import _from_toml, _to_json, _to_msgpack, _to_toml, _to_yaml
 
 toml_string = """[movies.Spaceballs]
 imdb_stars = 7.1
@@ -30,16 +31,15 @@ role = "Barf"
 
 
 class TestConverters:
-
     @pytest.fixture(autouse=True)
     def temp_dir_cleanup(self):
-        shutil.rmtree(tmp_dir, ignore_errors=True)
+        shutil.rmtree(str(tmp_dir), ignore_errors=True)
         try:
-            os.mkdir(tmp_dir)
+            os.mkdir(str(tmp_dir))
         except OSError:
             pass
         yield
-        shutil.rmtree(tmp_dir, ignore_errors=True)
+        shutil.rmtree(str(tmp_dir), ignore_errors=True)
 
     def test_to_toml(self):
         formatted = _to_toml(movie_data)
@@ -54,14 +54,14 @@ class TestConverters:
 
     def test_from_toml(self):
         result = _from_toml(toml_string)
-        assert result['movies']['Spaceballs']['length'] == 96
+        assert result["movies"]["Spaceballs"]["length"] == 96
 
     def test_from_toml_file(self):
         out_file = Path(tmp_dir, "toml_test.tml")
         assert not out_file.exists()
         out_file.write_text(toml_string)
         result = _from_toml(filename=out_file)
-        assert result['movies']['Spaceballs']['length'] == 96
+        assert result["movies"]["Spaceballs"]["length"] == 96
 
     def test_bad_from_toml(self):
         with pytest.raises(BoxError):
@@ -82,3 +82,11 @@ class TestConverters:
         _to_yaml(movie_data, filename=m_file)
         assert "Rick Moranis" in open(m_file).read()
         assert yaml.load(open(m_file), Loader=yaml.SafeLoader) == yaml.load(movie_string, Loader=yaml.SafeLoader)
+
+    def test_to_msgpack(self):
+        m_file = os.path.join(tmp_dir, "movie_data")
+        msg_data = _to_msgpack(movie_data)
+        assert b"Rick Moranis" in msg_data
+        _to_msgpack(movie_data, filename=m_file)
+        assert b"Rick Moranis" in open(m_file, "rb").read()
+        assert msgpack.unpack(open(m_file, "rb")) == msgpack.unpackb(msg_data)
